import { PrismaService } from "@/prisma/prisma.service";
import { checkUserIsAdmin } from "@/utils/checkUser";
import { ForbiddenException } from "@nestjs/common";
// biome-ignore lint/style/useImportType:
import { Test, TestingModule } from "@nestjs/testing";
import { PromoCodeService } from "./promoCode.service";

jest.mock("../utils/checkUser");

describe("PromoCodeService", () => {
	let service: PromoCodeService;
	let prisma: PrismaService;

	const mockPrismaService = {
		promoCode: {
			findMany: jest.fn(),
			create: jest.fn(),
			findUnique: jest.fn(),
			update: jest.fn(),
			delete: jest.fn(),
		},
	};

	beforeEach(async () => {
		const module: TestingModule = await Test.createTestingModule({
			providers: [
				PromoCodeService,
				{ provide: PrismaService, useValue: mockPrismaService },
			],
		}).compile();

		service = module.get<PromoCodeService>(PromoCodeService);
		prisma = module.get<PrismaService>(PrismaService);
	});

	afterEach(() => {
		jest.clearAllMocks();
	});

	describe("getPromoCodes", () => {
		it("should get promo codes if user is admin", async () => {
			(checkUserIsAdmin as jest.Mock).mockResolvedValue(true);
			const mockPromoCodes = [
				{ id: "1", name: "PROMO10", value: 10 },
				{ id: "2", name: "PROMO20", value: 20 },
			];
			mockPrismaService.promoCode.findMany.mockResolvedValue(mockPromoCodes);

			const result = await service.getPromoCodes("user-id");

			expect(checkUserIsAdmin).toHaveBeenCalledWith("user-id");
			expect(prisma.promoCode.findMany).toHaveBeenCalledWith({
				orderBy: { name: "asc" },
				select: { id: true, name: true, value: true },
			});
			expect(result).toEqual(mockPromoCodes);
		});

		it("should throw ForbiddenException if user is not admin", async () => {
			(checkUserIsAdmin as jest.Mock).mockRejectedValue(
				new ForbiddenException("Not an admin"),
			);

			await expect(service.getPromoCodes("user-id")).rejects.toThrow(ForbiddenException);

			expect(checkUserIsAdmin).toHaveBeenCalledWith("user-id");
			expect(prisma.promoCode.findMany).not.toHaveBeenCalled();
		});
	});
});
